summaryrefslogtreecommitdiffstats
path: root/kplato/kptproject.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /kplato/kptproject.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'kplato/kptproject.h')
-rw-r--r--kplato/kptproject.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kplato/kptproject.h b/kplato/kptproject.h
index d0dd1eb9..14f03384 100644
--- a/kplato/kptproject.h
+++ b/kplato/kptproject.h
@@ -223,11 +223,11 @@ public:
Accounts &accounts() { return m_accounts; }
/// Set current schedule to schedule with identity id, for me and my children
virtual void setCurrentSchedule(long id);
/// Create new schedule with unique id.
MainSchedule *createSchedule(TQString name, Schedule::Type type);
/// Set parent schedule for my children
virtual void setParentSchedule(Schedule *sch);
protected:
@@ -267,7 +267,7 @@ private:
#ifndef NDEBUG
#include <tqcstring.h>
public:
- void printDebug(bool children, TQCString indent);
+ void printDebug(bool tqchildren, TQCString indent);
void printCalendarDebug(TQCString indent="");
#ifdef DEBUGPERT
static void pert_test();
@@ -223,11 +223,11 @@ public:
Accounts &accounts() { return m_accounts; }
- /// Set current schedule to schedule with identity id, for me and my children
+ /// Set current schedule to schedule with identity id, for me and my tqchildren
virtual void setCurrentSchedule(long id);
/// Create new schedule with unique id.
@@ -223,11 +223,11 @@ public:
/// Create new schedule with unique id.
MainSchedule *createSchedule(TQString name, Schedule::Type type);
- /// Set parent schedule for my children
+ /// Set parent schedule for my tqchildren
virtual void setParentSchedule(Schedule *sch);
protected: